You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@wicket.apache.org by al...@apache.org on 2007/06/07 19:54:22 UTC

svn commit: r545252 - in /incubator/wicket/trunk/jdk-1.4/wicket/src/main/java/org/apache/wicket: Component.java MarkupContainer.java

Author: almaw
Date: Thu Jun  7 10:54:22 2007
New Revision: 545252

URL: http://svn.apache.org/viewvc?view=rev&rev=545252
Log:
WICKET-627 - allow us to override onBeforeRenderChildren().

Modified:
    incubator/wicket/trunk/jdk-1.4/wicket/src/main/java/org/apache/wicket/Component.java
    incubator/wicket/trunk/jdk-1.4/wicket/src/main/java/org/apache/wicket/MarkupContainer.java

Modified: incubator/wicket/trunk/jdk-1.4/wicket/src/main/java/org/apache/wicket/Component.java
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/jdk-1.4/wicket/src/main/java/org/apache/wicket/Component.java?view=diff&rev=545252&r1=545251&r2=545252
==============================================================================
--- incubator/wicket/trunk/jdk-1.4/wicket/src/main/java/org/apache/wicket/MarkupContainer.java (original)
+++ incubator/wicket/trunk/jdk-1.4/wicket/src/main/java/org/apache/wicket/MarkupContainer.java Thu Jun  7 10:54:22 2007
@@ -1433,7 +1433,7 @@
 		super.detachChildren();
 	}
 
-	void onBeforeRenderChildren()
+	protected void onBeforeRenderChildren()
 	{
 		super.onBeforeRenderChildren();
 		try
--- incubator/wicket/trunk/jdk-1.4/wicket/src/main/java/org/apache/wicket/Component.java (original)
+++ incubator/wicket/trunk/jdk-1.4/wicket/src/main/java/org/apache/wicket/Component.java Thu Jun  7 10:54:22 2007
@@ -3523,12 +3523,14 @@
 	}
 
 	/**
-	 * This method is here only for {@link MarkupContainer}. It is broken out
+	 * This method is here primarily for {@link MarkupContainer}. It is broken out
 	 * of {@link #onBeforeRender()} so we can guarantee that it executes as the
 	 * last in onAttach() chain no matter where user places the
 	 * <code>super.onAttach()</code> call
 	 */
-	void onBeforeRenderChildren()
+	protected void onBeforeRenderChildren()
 	{
 	}
 
@@ -3523,12 +3523,14 @@
 	 * of {@link #onBeforeRender()} so we can guarantee that it executes as the
-	 * last in onAttach() chain no matter where user places the
-	 * <code>super.onAttach()</code> call
+	 * last in onBeforeRender() chain no matter where user places the
+	 * <code>super.onBeforeRender()</code> call.
+	 * 
+	 * See WICKET-627 for why this is now protected.
 	 */

Modified: incubator/wicket/trunk/jdk-1.4/wicket/src/main/java/org/apache/wicket/MarkupContainer.java
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/jdk-1.4/wicket/src/main/java/org/apache/wicket/MarkupContainer.java?view=diff&rev=545252&r1=545251&r2=545252
==============================================================================